==> cryptol-2.5.0.20180515-57-x86_64.pkg.tar.xz: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptol
version: 2.5.0
id: cryptol-2.5.0-ATXiXdTYYtGKcTDZJlzHCS
key: cryptol-2.5.0-ATXiXdTYYtGKcTDZJlzHCS
license: BSD-3-Clause
copyright: 2013-2017 Galois Inc.
maintainer: cryptol@galois.com
author: Galois, Inc.
homepage: http://www.cryptol.net/
synopsis: Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.
category: Language
abi: 0344cec7ee97d3a7d6f404c34f224c19
exposed: True
exposed-modules:
    Cryptol.Eval Cryptol.Eval.Arch Cryptol.Eval.Env Cryptol.Eval.Monad
    Cryptol.Eval.Reference Cryptol.Eval.Type Cryptol.Eval.Value
    Cryptol.IR.FreeVars Cryptol.ModuleSystem Cryptol.ModuleSystem.Base
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Exports
    Cryptol.ModuleSystem.InstantiateModule
    Cryptol.ModuleSystem.Interface Cryptol.ModuleSystem.Monad
    Cryptol.ModuleSystem.Name Cryptol.ModuleSystem.NamingEnv
    Cryptol.ModuleSystem.Renamer Cryptol.Parser Cryptol.Parser.AST
    Cryptol.Parser.Lexer Cryptol.Parser.Name Cryptol.Parser.Names
    Cryptol.Parser.NoInclude Cryptol.Parser.NoPat
    Cryptol.Parser.Position Cryptol.Parser.Unlit Cryptol.Parser.Utils
    Cryptol.Prims.Eval Cryptol.Prims.Syntax Cryptol.REPL.Command
    Cryptol.REPL.Monad Cryptol.REPL.Trie Cryptol.Symbolic
    Cryptol.Symbolic.Prims Cryptol.Symbolic.Value
    Cryptol.Testing.Concrete Cryptol.Testing.Random
    Cryptol.Transform.AddModParams Cryptol.Transform.MonoValues
    Cryptol.Transform.Specialize Cryptol.TypeCheck
    Cryptol.TypeCheck.AST Cryptol.TypeCheck.CheckModuleInstance
    Cryptol.TypeCheck.Default Cryptol.TypeCheck.Depends
    Cryptol.TypeCheck.Error Cryptol.TypeCheck.Infer
    Cryptol.TypeCheck.InferTypes Cryptol.TypeCheck.Instantiate
    Cryptol.TypeCheck.Kind Cryptol.TypeCheck.Monad Cryptol.TypeCheck.PP
    Cryptol.TypeCheck.Parseable Cryptol.TypeCheck.Sanity
    Cryptol.TypeCheck.SimpType Cryptol.TypeCheck.SimpleSolver
    Cryptol.TypeCheck.Solve Cryptol.TypeCheck.Solver.Class
    Cryptol.TypeCheck.Solver.Improve Cryptol.TypeCheck.Solver.InfNat
    Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.Type
    Cryptol.TypeCheck.TypeMap Cryptol.TypeCheck.TypeOf
    Cryptol.TypeCheck.TypePat Cryptol.TypeCheck.Unify
    Cryptol.Utils.Debug Cryptol.Utils.Ident Cryptol.Utils.Logger
    Cryptol.Utils.Misc Cryptol.Utils.PP Cryptol.Utils.Panic
    Cryptol.Utils.Patterns Cryptol.Version
hidden-modules: Cryptol.Parser.LexerUtils
                Cryptol.Parser.ParserUtils Cryptol.Prelude Paths_cryptol GitRev
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptol-2.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptol-2.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/cryptol
hs-libraries: HScryptol-2.5.0-ATXiXdTYYtGKcTDZJlzHCS
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    bytestring-0.10.8.2 array-0.5.2.0 containers-0.5.11.0
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
    GraphSCC-1.0.4-H3NchjVfsifDXhqutugzy
    heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR
    monad-control-1.0.2.3-87lWNcomfXpJ29QmdQvcek
    monadLib-3.7.3-IHqfI8sONdL8ofFczgj7jY pretty-1.1.3.6
    process-1.6.3.0 random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    sbv-7.10-BNhgQr8I6dr37pJ9PlVnuy
    simple-smt-0.9.1-73rH3oTvGg61ZDKsrAFdj8
    strict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z text-1.2.3.0
    tf-random-0.5-I39p3qgWMzeLwkvBknVuZq
    transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ mtl-2.2.2
    time-1.8.0.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC=9ed49284e061b5dda1f602d003f0f2bf
             GraphSCC-1.0.4-H3NchjVfsifDXhqutugzy=e16cadd27e6b215da0c16c5645c257df
             heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR=b674b1d4ce86ccb75d27fd2bf46cce9b
             monad-control-1.0.2.3-87lWNcomfXpJ29QmdQvcek=4701eb7c70a10f72aec80f45872b6148
             monadLib-3.7.3-IHqfI8sONdL8ofFczgj7jY=da6e315e5fa4300fe251551461c4fc71
             pretty-1.1.3.6=242598bba36778e604a1e89d5c7ce1a8
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             sbv-7.10-BNhgQr8I6dr37pJ9PlVnuy=31d76c3131e4848e992baef7d72661ce
             simple-smt-0.9.1-73rH3oTvGg61ZDKsrAFdj8=c711c8db4247147ae56df2b88bf2f4f5
             strict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z=a5277c03e2654628d5ef4c621185feee
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             tf-random-0.5-I39p3qgWMzeLwkvBknVuZq=a5f9e7f35c2dd2438de490ec75468716
             transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ=ff843a556414f5766b414ccfa8c6dff6
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
haddock-interfaces: /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html: /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cryptol-2.5.0.20180515-58-x86_64.pkg.tar.xz: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptol
version: 2.5.0
id: cryptol-2.5.0-2Z4HzXi0uKzBRWnpHbp6XV
key: cryptol-2.5.0-2Z4HzXi0uKzBRWnpHbp6XV
license: BSD-3-Clause
copyright: 2013-2017 Galois Inc.
maintainer: cryptol@galois.com
author: Galois, Inc.
homepage: http://www.cryptol.net/
synopsis: Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.
category: Language
abi: be928994ba69af2b2a39321c6e8e63ce
exposed: True
exposed-modules:
    Cryptol.Eval Cryptol.Eval.Arch Cryptol.Eval.Env Cryptol.Eval.Monad
    Cryptol.Eval.Reference Cryptol.Eval.Type Cryptol.Eval.Value
    Cryptol.IR.FreeVars Cryptol.ModuleSystem Cryptol.ModuleSystem.Base
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Exports
    Cryptol.ModuleSystem.InstantiateModule
    Cryptol.ModuleSystem.Interface Cryptol.ModuleSystem.Monad
    Cryptol.ModuleSystem.Name Cryptol.ModuleSystem.NamingEnv
    Cryptol.ModuleSystem.Renamer Cryptol.Parser Cryptol.Parser.AST
    Cryptol.Parser.Lexer Cryptol.Parser.Name Cryptol.Parser.Names
    Cryptol.Parser.NoInclude Cryptol.Parser.NoPat
    Cryptol.Parser.Position Cryptol.Parser.Unlit Cryptol.Parser.Utils
    Cryptol.Prims.Eval Cryptol.Prims.Syntax Cryptol.REPL.Command
    Cryptol.REPL.Monad Cryptol.REPL.Trie Cryptol.Symbolic
    Cryptol.Symbolic.Prims Cryptol.Symbolic.Value
    Cryptol.Testing.Concrete Cryptol.Testing.Random
    Cryptol.Transform.AddModParams Cryptol.Transform.MonoValues
    Cryptol.Transform.Specialize Cryptol.TypeCheck
    Cryptol.TypeCheck.AST Cryptol.TypeCheck.CheckModuleInstance
    Cryptol.TypeCheck.Default Cryptol.TypeCheck.Depends
    Cryptol.TypeCheck.Error Cryptol.TypeCheck.Infer
    Cryptol.TypeCheck.InferTypes Cryptol.TypeCheck.Instantiate
    Cryptol.TypeCheck.Kind Cryptol.TypeCheck.Monad Cryptol.TypeCheck.PP
    Cryptol.TypeCheck.Parseable Cryptol.TypeCheck.Sanity
    Cryptol.TypeCheck.SimpType Cryptol.TypeCheck.SimpleSolver
    Cryptol.TypeCheck.Solve Cryptol.TypeCheck.Solver.Class
    Cryptol.TypeCheck.Solver.Improve Cryptol.TypeCheck.Solver.InfNat
    Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.Type
    Cryptol.TypeCheck.TypeMap Cryptol.TypeCheck.TypeOf
    Cryptol.TypeCheck.TypePat Cryptol.TypeCheck.Unify
    Cryptol.Utils.Debug Cryptol.Utils.Ident Cryptol.Utils.Logger
    Cryptol.Utils.Misc Cryptol.Utils.PP Cryptol.Utils.Panic
    Cryptol.Utils.Patterns Cryptol.Version
hidden-modules: Cryptol.Parser.LexerUtils
                Cryptol.Parser.ParserUtils Cryptol.Prelude Paths_cryptol GitRev
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptol-2.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptol-2.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/cryptol
hs-libraries: HScryptol-2.5.0-2Z4HzXi0uKzBRWnpHbp6XV
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    bytestring-0.10.8.2 array-0.5.2.0 containers-0.5.11.0
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2
    gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
    GraphSCC-1.0.4-H3NchjVfsifDXhqutugzy
    heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR
    monad-control-1.0.2.3-KD4Vsg6Ia0X5RLt8TMMDV6
    monadLib-3.7.3-IHqfI8sONdL8ofFczgj7jY pretty-1.1.3.6
    process-1.6.3.0 random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    sbv-7.10-G3hy9XEH92mDDZNltDYTWU
    simple-smt-0.9.1-73rH3oTvGg61ZDKsrAFdj8
    strict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z text-1.2.3.0
    tf-random-0.5-I39p3qgWMzeLwkvBknVuZq
    transformers-base-0.4.5.2-CJkbYH4N4LV8hMEohn0j3d mtl-2.2.2
    time-1.8.0.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC=9ed49284e061b5dda1f602d003f0f2bf
             GraphSCC-1.0.4-H3NchjVfsifDXhqutugzy=e16cadd27e6b215da0c16c5645c257df
             heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR=b674b1d4ce86ccb75d27fd2bf46cce9b
             monad-control-1.0.2.3-KD4Vsg6Ia0X5RLt8TMMDV6=c021194f497af7f0c1d884cb305008e2
             monadLib-3.7.3-IHqfI8sONdL8ofFczgj7jY=da6e315e5fa4300fe251551461c4fc71
             pretty-1.1.3.6=242598bba36778e604a1e89d5c7ce1a8
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             sbv-7.10-G3hy9XEH92mDDZNltDYTWU=9f1cfccf7994389f3f7e0f768ee51cfb
             simple-smt-0.9.1-73rH3oTvGg61ZDKsrAFdj8=c711c8db4247147ae56df2b88bf2f4f5
             strict-0.3.2-GUMMwuTAWLDDoRWXG04D6Z=a5277c03e2654628d5ef4c621185feee
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             tf-random-0.5-I39p3qgWMzeLwkvBknVuZq=a5f9e7f35c2dd2438de490ec75468716
             transformers-base-0.4.5.2-CJkbYH4N4LV8hMEohn0j3d=85e83aa98f31119a75b463e70412c07f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
haddock-interfaces: /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html: /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
